@@ -51,7 +51,7 @@ dist.plot.data.frame <- function(object,
 
         A <- find.strata(data    = data,
                          strata  = match.index,
-                         matched = TRUE)        
+                         match   = TRUE)        
         match.index        <- A[[1]]
         name.match.index   <- A[[2]]
 
@@ -157,3 +157,31 @@ dist.plot.data.frame <- function(object,
   
 }
 
+#dist.plot.data.frame <- function(object,
+#                                 sel           = NULL,
+#                                 treat         = NULL,
+#                                 stratum.index = NULL,
+#                                 match.index   = NULL,
+#                                 plot.type     = 1,
+#                                 cat.levels    = 10,
+#                                 plot.levels   = 5,
+#                                 compare       = FALSE,
+#                                 label.match   = NULL,
+#                                 label.stratum = "Stratum",
+#                                 with.legend  = TRUE,                
+#                                 legend.title = NULL,
+#                                 legend.cex   = 0.9,              
+#                                 myoma        = c(2,2,2,2),
+#                                 mymar        = c(2,4,1,2),
+#                                 width        = 1,
+#                                 xlim         = NULL,
+#                                 ylim         = NULL,
+#                                 col          = NULL,
+#                                 las          = 1,
+#                                 font.main    = 2,
+#                                 font         = 1,
+#                                 main         = NULL,
+#                                 main.cex     = 1.2,
+#                                 sub.cex      = 0.9,
+#                                 bar.cex      = 0.8,
+#                                 ...) 
