@@ -1,7 +1,9 @@
 
-print.stratified.pscore <- function(object,
+print.stratified.pscore <- function(x,
                                 ...){
 
+  object <- x
+  
   cat("\n Stratified by: ", object$stratified.by, "\n")
 
   cat("\n Strata information: \n\n")
@@ -11,7 +13,7 @@ print.stratified.pscore <- function(object,
                      as.numeric(table(object$stratum.index)),
                      round(as.numeric(table(object$stratum.index))/dim(object$data)[1],3)))
   
-  colnames(df) <- c("  Strata bounds","    n","    n (per cent)")
+  colnames(df) <- c("  Strata bounds","    n","    n  (proportion)")
 
   print(df)
 
